@@ -60,6 +60,20 @@ int OsiRowCutDebugger::validateCuts(const OsiCuts & cs,
       for (k=0; k<n; k++){
 	int column=indices[k];
         std::cout<<"( "<<column<<" , "<<elements[k]<<" ) ";
+	if ((k%4)==3)
+	  std::cout <<std::endl;
+      }
+      std::cout <<std::endl;
+      std::cout <<"Non zero solution values are"<<std::endl;
+      int j=0;
+      for (k=0; k<n; k++){
+	int column=indices[k];
+	if (fabs(optimalSolution_[column])>1.0e-9) {
+	  std::cout<<"( "<<column<<" , "<<optimalSolution_[column]<<" ) ";
+	  if ((j%4)==3)
+	    std::cout <<std::endl;
+	  j++;
+	}
       }
       std::cout <<std::endl;
       nbad++;
@@ -103,8 +117,22 @@ bool OsiRowCutDebugger::invalidCut(const OsiRowCut & rcut) const
     for (k=0; k<n; k++){
       int column=indices[k];
       std::cout<<"( "<<column<<" , "<<elements[k]<<" ) ";
+      if ((k%4)==3)
+	std::cout <<std::endl;
     }
-    std::cout<<std::endl;
+    std::cout <<std::endl;
+    std::cout <<"Non zero solution values are"<<std::endl;
+    int j=0;
+    for (k=0; k<n; k++){
+      int column=indices[k];
+      if (fabs(optimalSolution_[column])>1.0e-9) {
+	std::cout<<"( "<<column<<" , "<<optimalSolution_[column]<<" ) ";
+	if ((j%4)==3)
+	  std::cout <<std::endl;
+	j++;
+      }
+    }
+    std::cout <<std::endl;
     bad=true;
   }
   return bad;
@@ -122,6 +150,10 @@ bool OsiRowCutDebugger::onOptimalPath(const OsiSolverInterface & si) const
     const double * colupper = si.getColUpper();
     bool onOptimalPath=true;
     for (i=0;i<numberColumns_;i++) {
+      if (collower[i]>colupper[i]+1.0e-12) {
+	printf("Infeasible bounds for %d - %g, %g\n",
+	       i,collower[i],colupper[i]);
+      }
       if (si.isInteger(i)) {
 	// value of integer variable in solution
 	double value=optimalSolution_[i]; 
@@ -907,6 +939,48 @@ bool OsiRowCutDebugger::activate( const OsiSolverInterface & si,
     expectedNumberColumns=1224;
   }
 
+  // gesa2_o
+  else if ( modelL == "gesa2_o" ) {
+    probType=generalMip;
+	int intIndicesV[]={
+315 ,316 ,328 ,329 ,341 ,342 ,354 ,355 ,367 ,368 ,
+380 ,381 ,393 ,394 ,406 ,407 ,419 ,420 ,423 ,427 ,
+428 ,432 ,433 ,436 ,440 ,441 ,445 ,446 ,449 ,453 ,
+454 ,458 ,459 ,462 ,466 ,467 ,471 ,472 ,475 ,479 ,
+480 ,484 ,485 ,492 ,493 ,497 ,498 ,505 ,506 ,510 ,
+511 ,514 ,518 ,519 ,523 ,524 ,527 ,531 ,532 ,536 ,
+537 ,539 ,540 ,543 ,544 ,545 ,549 ,550 ,552 ,553 ,
+556 ,557 ,558 ,562 ,563 ,565 ,566 ,569 ,570 ,571 ,
+575 ,576 ,577 ,579 ,582 ,583 ,584 ,588 ,589 ,592 ,
+596 ,597 ,601 ,602 ,605 ,609 ,610 ,614 ,615 ,735 ,
+739 ,740 ,748 ,826 ,839 ,851 ,852 ,855 ,856 ,889 ,
+1136 ,1137 ,1138 ,1139 ,1140 ,1142 ,1143 ,1144 ,1145 ,1146 ,
+1147 ,1148 ,1149 ,1152 ,1153 ,1154 ,1155 ,1156 ,1157 ,1158 ,
+1159 ,1165 ,1175 ,1193 ,1194 ,1195 ,1200 ,1201 ,1202 ,1203 ,
+1204 ,1205 ,1206 ,1207 ,1208 ,1209 ,1210 ,1211 ,1212 ,1213 ,
+1214 ,1215 ,1216 ,1220 ,1221 ,1222 ,1223 };
+	double intSolnV[]={
+1. ,2. ,1. ,2. ,1. ,2. ,1. ,2. ,1. ,2. ,
+1. ,2. ,1. ,2. ,1. ,2. ,1. ,2. ,1. ,2. ,
+2. ,1. ,2. ,3. ,2. ,2. ,1. ,2. ,3. ,2. ,
+2. ,1. ,2. ,3. ,2. ,2. ,1. ,2. ,2. ,2. ,
+2. ,1. ,2. ,2. ,2. ,1. ,2. ,2. ,2. ,1. ,
+2. ,1. ,2. ,2. ,1. ,2. ,2. ,2. ,2. ,1. ,
+2. ,1. ,3. ,4. ,3. ,2. ,1. ,2. ,1. ,3. ,
+4. ,3. ,2. ,1. ,2. ,1. ,3. ,4. ,3. ,2. ,
+1. ,2. ,1. ,3. ,4. ,3. ,2. ,1. ,2. ,3. ,
+3. ,2. ,1. ,2. ,1. ,2. ,2. ,1. ,2. ,1. ,
+2. ,2. ,2. ,1. ,1. ,1. ,1. ,4. ,1. ,1. ,
+1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,
+1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,
+1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,
+1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,
+1. ,1. ,1. ,1. ,1. ,1. ,1. };
+    int vecLen = sizeof(intIndicesV)/sizeof(int);
+    intSoln.setVector(vecLen,intIndicesV,intSolnV);
+    expectedNumberColumns=1224;
+  }
+
   // gesa3
   else if ( modelL == "gesa3" ) {
     probType=generalMip;
@@ -1133,10 +1207,12 @@ bool OsiRowCutDebugger::activate( const OsiSolverInterface & si,
   // bell5
   else if ( modelL == "bell5" ) {
     probType=generalMip;
-    int intIndicesV[]={0,1,2,3,4,6,12,13,15,33,34,36,47,48,49,50,
-		       51,52,53,54,56};
-    double intSolnV[] = {1.,1.,1.,1.,1.,1.,1.,1.,1.,1.,1.,11.,
-	2.,38.,2.,498.,125.,10.,17.,41.,19.};
+    int intIndicesV[]={
+      0 ,1 ,2 ,3 ,4 ,6 ,33 ,34 ,36 ,47 ,
+      48 ,49 ,50 ,51 ,52 ,53 ,54 ,56 };
+    double intSolnV[]={
+      1. ,1. ,1. ,1. ,1. ,1. ,1. ,1. ,11. ,2. ,
+      38. ,2. ,498. ,125. ,10. ,17. ,41. ,19. };
     int vecLen = sizeof(intIndicesV)/sizeof(int);
     intSoln.setVector(vecLen,intIndicesV,intSolnV);
     expectedNumberColumns=104;
